export type OnigurumaToEsOptions = {
    accuracy?: "default" | "strict" | "loose";
    avoidSubclass?: boolean;
    flags?: import("./tokenize.js").OnigurumaFlags;
    global?: boolean;
    hasIndices?: boolean;
    maxRecursionDepth?: number | null;
    target?: "auto" | "ES2018" | "ES2024" | "ES2025";
    tmGrammar?: boolean;
    verbose?: boolean;
};
export type EmulatedRegExpOptions = {
    useEmulationGroups?: boolean;
    strategy?: string;
};
/**
Works the same as JavaScript's native `RegExp` constructor in all contexts, but can be given
results from `toDetails` to produce the same result as `toRegExp`.
@class
@augments RegExp
@param {string | EmulatedRegExp} pattern
@param {string} [flags]
@param {EmulatedRegExpOptions} [options]
*/
export class EmulatedRegExp extends RegExp {
    constructor(pattern: any, flags: any, options: any);
    #private;
}
/**
@typedef {{
  accuracy?: keyof Accuracy;
  avoidSubclass?: boolean;
  flags?: import('./tokenize.js').OnigurumaFlags;
  global?: boolean;
  hasIndices?: boolean;
  maxRecursionDepth?: number | null;
  target?: keyof Target;
  tmGrammar?: boolean;
  verbose?: boolean;
}} OnigurumaToEsOptions
@typedef {{
  useEmulationGroups?: boolean;
  strategy?: string;
}} EmulatedRegExpOptions
*/
/**
Accepts an Oniguruma pattern and returns the details needed to construct an equivalent JavaScript `RegExp`.
@param {string} pattern Oniguruma regex pattern.
@param {OnigurumaToEsOptions} [options]
@returns {{
  pattern: string;
  flags: string;
  subclass?: EmulatedRegExpOptions;
}}
*/
export function toDetails(pattern: string, options?: OnigurumaToEsOptions): {
    pattern: string;
    flags: string;
    subclass?: EmulatedRegExpOptions;
};
/**
Returns an Oniguruma AST generated from an Oniguruma pattern.
@param {string} pattern Oniguruma regex pattern.
@param {{
  flags?: import('./tokenize.js').OnigurumaFlags;
}} [options]
@returns {import('./parse.js').OnigurumaAst}
*/
export function toOnigurumaAst(pattern: string, options?: {
    flags?: import("./tokenize.js").OnigurumaFlags;
}): import("./parse.js").OnigurumaAst;
/**
Accepts an Oniguruma pattern and returns an equivalent JavaScript `RegExp`.
@param {string} pattern Oniguruma regex pattern.
@param {OnigurumaToEsOptions} [options]
@returns {RegExp | EmulatedRegExp}
*/
export function toRegExp(pattern: string, options?: OnigurumaToEsOptions): RegExp | EmulatedRegExp;
